@@ -51,6 +51,7 @@
 /* Called from the original process before and after fork */
 void seahorse_agent_prefork ();
 void seahorse_agent_postfork (pid_t child);
+void seahorse_agent_childsetup ();
 
 /* Called in the new child process */
 gboolean seahorse_agent_init ();
@@ -74,23 +75,27 @@ const gchar* seahorse_agent_io_get_socket ();
 int seahorse_agent_io_init ();
 void seahorse_agent_io_uninit ();
 void seahorse_agent_io_reply (SeahorseAgentConn *rq, gboolean ok, const gchar *response);
+void seahorse_agent_io_data (SeahorseAgentConn *cn, const gchar *data);
 
 /* -----------------------------------------------------------------------------
  * seahorse-agent-actions.c
  */
 
+#define SEAHORSE_AGENT_PASS_AS_DATA    0x00000001
+
 typedef struct _SeahorseAgentPassReq {
     const gchar *id;
     const gchar *errmsg;
     const gchar *prompt;
     const gchar *description;
     SeahorseAgentConn *request;
+    guint32 flags;
 } SeahorseAgentPassReq;
 
 void seahorse_agent_actions_init ();
 void seahorse_agent_actions_uninit ();
-void seahorse_agent_actions_getpass (SeahorseAgentConn *rq, gchar *id, gchar *errmsg,
-                                     gchar *prompt, gchar *desc);
+void seahorse_agent_actions_getpass (SeahorseAgentConn *rq, guint32 flags, gchar *id,
+                                     gchar *errmsg, gchar *prompt, gchar *desc);
 void seahorse_agent_actions_clrpass (SeahorseAgentConn *rq, gchar *id);
 void seahorse_agent_actions_doneauth (SeahorseAgentPassReq *pr, gboolean authorized);
 void seahorse_agent_actions_donepass (SeahorseAgentPassReq *pr, const gchar *pass);
@@ -136,6 +141,7 @@ void seahorse_agent_status_update ();
 /* Called from the original process before and after fork */
 void     seahorse_agent_ssh_prefork ();
 void     seahorse_agent_ssh_postfork (pid_t child);
+void     seahorse_agent_ssh_childsetup ();
 
 gboolean seahorse_agent_ssh_init ();
 GList*   seahorse_agent_ssh_cached_keys ();
