@@ -78,8 +78,21 @@ utf8_validate (const gchar *text)
     return result;
 }
 
+static gboolean
+key_press (GtkWidget *widget, GdkEventKey *event, gpointer data)
+{
+    /* Close the dialog when hitting "Esc". */
+    if (event->keyval == GDK_Escape)
+    {
+        gtk_dialog_response(GTK_DIALOG (widget), GTK_RESPONSE_REJECT);
+        return TRUE;
+    }
+    
+    return FALSE;
+}
+
 static void
-grab_keyboard (GtkWidget *win, GdkEvent * event, gpointer data)
+grab_keyboard (GtkWidget *win, GdkEvent *event, gpointer data)
 {
 #ifndef _DEBUG
     if (gdk_keyboard_grab (win->window, FALSE, gdk_event_get_time (event)))
@@ -258,6 +271,8 @@ seahorse_passphrase_prompt_show (const gchar *title, const gchar *description,
     g_signal_connect_object (G_OBJECT (entry), "focus_in_event",
                              G_CALLBACK (gtk_widget_grab_default), G_OBJECT (w), 0);
     gtk_widget_grab_default (w);
+    
+    g_signal_connect (dialog, "key_press_event", G_CALLBACK (key_press), NULL);
 
     gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_CENTER);
     gtk_window_set_keep_above(GTK_WINDOW (dialog), TRUE);
@@ -499,7 +514,7 @@ gpg_detect_agent ()
  * SSH AGENT 
  */
 
-const gchar REQ_MESSAGE[] = { 0x01, 0x00, 0x00, 0x00, SEAHORSE_SSH_PING_MSG };
+const guchar REQ_MESSAGE[] = { 0x00, 0x00, 0x00, 0x01, SEAHORSE_SSH_PING_MSG };
 const guint RESP_INDEX = 4;
 const guint RESP_VALUE = SEAHORSE_SSH_PING_MSG;
 
@@ -509,7 +524,7 @@ ssh_detect_agent ()
     SeahorseAgentType ret;
     const gchar *socketpath;
     struct sockaddr_un sunaddr;
-    gchar buf[16];
+    guchar buf[16];
     GIOChannel *io;
     int agentfd;
     gsize bytes_read = 0;
@@ -532,7 +547,7 @@ ssh_detect_agent ()
     memset (&sunaddr, 0, sizeof (sunaddr));
     sunaddr.sun_family = AF_UNIX;
     g_strlcpy (sunaddr.sun_path, socketpath, sizeof (sunaddr.sun_path));
-    if (connect (agentfd, (struct sockaddr*) &sunaddr, sizeof sunaddr) < 0) {
+    if (connect (agentfd, (struct sockaddr*) &sunaddr, sizeof (sunaddr)) < 0) {
         g_warning ("couldn't connect to SSH agent at: %s: %s", socketpath, 
                    g_strerror (errno));
         close (agentfd);
@@ -545,9 +560,9 @@ ssh_detect_agent ()
     g_io_channel_set_buffered (io, FALSE);
 
     /* Send and receive our message */
-    if (g_io_channel_write_chars (io, REQ_MESSAGE, sizeof (REQ_MESSAGE), NULL, 
+    if (g_io_channel_write_chars (io, (const gchar*)REQ_MESSAGE, sizeof (REQ_MESSAGE), NULL, 
                                   &err) == G_IO_STATUS_NORMAL) {
-        g_io_channel_read_chars (io, buf, sizeof (buf), &bytes_read, &err);
+        g_io_channel_read_chars (io, (gchar*)buf, sizeof (buf), &bytes_read, &err);
     }
     
     if (!err) {
