@@ -334,7 +334,7 @@ set_selected_key (SeahorseWidget *swidget, SeahorseKey *skey)
 }
 
 static void
-set_numbered_status (SeahorseWidget *swidget, const gchar *t1, const gchar *t2, guint num)
+set_numbered_status (SeahorseWidget *swidget, const gchar *message, guint num)
 {
     GtkStatusbar *status;
     guint id;
@@ -346,7 +346,7 @@ set_numbered_status (SeahorseWidget *swidget, const gchar *t1, const gchar *t2,
     id = gtk_statusbar_get_context_id (status, "key-manager");
     gtk_statusbar_pop (status, id);
     
-    msg = g_strdup_printf (ngettext (t1, t2, num), num);
+    msg = g_strdup_printf (message, num);
     gtk_statusbar_push (status, id, msg);
     g_free (msg);
 }
@@ -401,8 +401,8 @@ imported_keys (SeahorseOperation *op, SeahorseWidget *swidget)
     set_selected_keys (swidget, keys);
     
     nkeys = g_list_length (keys);
-    set_numbered_status (swidget, _("Imported %d key"), 
-                                  _("Imported %d keys"), nkeys);
+    set_numbered_status (swidget, ngettext("Imported %d key", 
+            	        	           "Imported %d keys", nkeys), nkeys);
 }
 
 static void
@@ -475,6 +475,8 @@ import_text (SeahorseWidget *swidget, const gchar *text)
     GQuark ktype;
     guint len;
     
+    g_assert (text != NULL);
+    
     len = strlen (text);
     
     /* Figure out what key format we're dealing with here */
@@ -526,7 +528,8 @@ import_activate (GtkWidget *widget, SeahorseWidget *swidget)
 static void
 clipboard_received (GtkClipboard *board, const gchar *text, SeahorseWidget *swidget)
 {
-    import_text (swidget, text);
+    if (text != NULL)
+        import_text (swidget, text);
 }
 
 /* Pastes key from keyboard */
@@ -570,8 +573,8 @@ copy_done (SeahorseOperation *op, SeahorseWidget *swidget)
 
     num = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (op), "num-keys"));
     if (num > 0) {
-        set_numbered_status (swidget, _("Copied %d key"), 
-                                      _("Copied %d keys"), num);
+        set_numbered_status (swidget, ngettext ("Copied %d key", 
+                                                "Copied %d keys", num), num);
     }
 }
 
@@ -942,8 +945,8 @@ selection_changed (GtkTreeSelection *notused, SeahorseWidget *swidget)
     }
     
     if (selected) {
-        set_numbered_status (swidget, _("Selected %d key"),
-                                      _("Selected %d keys"), rows);
+        set_numbered_status (swidget, ngettext ("Selected %d key",
+                                                "Selected %d keys", rows), rows);
         
         keys = get_selected_keys (swidget);
 
